/*     */ package javax.xml.ws.spi;
/*     */ 
/*     */ import java.io.BufferedReader;
/*     */ import java.io.File;
/*     */ import java.io.FileInputStream;
/*     */ import java.io.InputStream;
/*     */ import java.io.InputStreamReader;
/*     */ import java.util.Properties;
/*     */ import javax.xml.ws.WebServiceException;
/*     */ 
/*     */ class FactoryFinder
/*     */ {
/*     */   private static Object newInstance(String className, ClassLoader classLoader)
/*     */   {
/*     */     try
/*     */     {
/*  65 */       Class spiClass = safeLoadClass(className, classLoader);
/*  66 */       return spiClass.newInstance();
/*     */     } catch (ClassNotFoundException x) {
/*  68 */       throw new WebServiceException("Provider " + className + " not found", x);
/*     */     } catch (Exception x) {
  /*  71 */     throw new WebServiceException("Provider " + className + " could not be instantiated: " + x, x);
/*     */     }
/*     */   }
/*     */ 
/*     */   static Object find(String factoryId, String fallbackClassName)
/*     */   {
              if (isOsgi()) {
		return lookupUsingOSGiServiceLoader(factoryId);
              }
/*     */     ClassLoader classLoader;
/*     */     try
/*     */     {
/* 101 */       classLoader = Thread.currentThread().getContextClassLoader();
/*     */     } catch (Exception x) {
/* 103 */       throw new WebServiceException(x.toString(), x);
/*     */     }
/*     */ 
/* 106 */     String serviceId = "META-INF/services/" + factoryId;
/*     */     try
/*     */     {
/* 109 */       InputStream is = null;
/* 110 */       if (classLoader == null)
/* 111 */         is = ClassLoader.getSystemResourceAsStream(serviceId);
/*     */       else {
/* 113 */         is = classLoader.getResourceAsStream(serviceId);
/*     */       }
/*     */ 
/* 116 */       if (is != null) {
/* 117 */         BufferedReader rd = new BufferedReader(new InputStreamReader(is, "UTF-8"));
/*     */ 
/* 120 */         String factoryClassName = rd.readLine();
/* 121 */         rd.close();
/*     */ 
/* 123 */         if ((factoryClassName != null) && (!"".equals(factoryClassName)))
/*     */         {
/* 125 */           return newInstance(factoryClassName, classLoader);
/*     */         }
/*     */       }
/*     */     }
/*     */     catch (Exception ex)
/*     */     {
/*     */     }
/*     */     try
/*     */     {
/* 134 */       String javah = System.getProperty("java.home");
/* 135 */       String configFile = javah + File.separator + "lib" + File.separator + "jaxws.properties";
/*     */ 
/* 137 */       File f = new File(configFile);
/* 138 */       if (f.exists()) {
/* 139 */         Properties props = new Properties();
/* 140 */         props.load(new FileInputStream(f));
/* 141 */         String factoryClassName = props.getProperty(factoryId);
/* 142 */         return newInstance(factoryClassName, classLoader);
/*     */       }
/*     */     }
/*     */     catch (Exception ex)
/*     */     {
/*     */     }
/*     */     try
/*     */     {
/* 150 */       String systemProp = System.getProperty(factoryId);
/*     */ 
/* 152 */       if (systemProp != null)
/* 153 */         return newInstance(systemProp, classLoader);
/*     */     }
/*     */     catch (SecurityException se)
/*     */     {
/*     */     }
/* 158 */     if (fallbackClassName == null) {
/* 159 */       throw new WebServiceException("Provider for " + factoryId + " cannot be found", null);
/*     */     }
/*     */ 
/* 163 */     return newInstance(fallbackClassName, classLoader);
/*     */   }
/*     */ 
/*     */   private static Class safeLoadClass(String className, ClassLoader classLoader)
/*     */     throws ClassNotFoundException
/*     */   {
/*     */     try
/*     */     {
/* 173 */       SecurityManager s = System.getSecurityManager();
/* 174 */       if (s != null) {
/* 175 */         int i = className.lastIndexOf('.');
/* 176 */         if (i != -1) {
/* 177 */           s.checkPackageAccess(className.substring(0, i));
/*     */         }
/*     */       }
/*     */ 
/* 181 */       if (classLoader == null) {
/* 182 */         return Class.forName(className);
/*     */       }
/* 184 */       return classLoader.loadClass(className);
/*     */     }
/*     */     catch (SecurityException se) {
/* 187 */       if ("com.sun.xml.internal.ws.spi.ProviderImpl".equals(className))
/* 188 */         return Class.forName(className); 
/* 189 */     throw se;
/*     */     }
/*     */   }

  private static final String OSGI_SERVICE_LOADER_CLASS_NAME = "org.glassfish.hk2.osgiresourcelocator.ServiceLoader";
  private static boolean isOsgi() {
    try {
      Class.forName(OSGI_SERVICE_LOADER_CLASS_NAME);
      return true;
    } catch(ClassNotFoundException cnfe) {
    }
    return false;
  }

  private static Object lookupUsingOSGiServiceLoader(String factoryId) {
    try {
      // Use reflection to avoid having any dependendcy on ServiceLoader class
      Class serviceClass = Class.forName(factoryId);
      Class[] args = new Class[]{serviceClass};
      Class target = Class.forName(OSGI_SERVICE_LOADER_CLASS_NAME);
      java.lang.reflect.Method m = target.getMethod("lookupProviderInstances");
      java.util.Iterator iter = ((Iterable)m.invoke(null, args)).iterator();
      return iter.hasNext()? iter.next() : null;
    } catch(Exception e) {
      // log and continue
      return null;
    }
  }
/*     */ }

/* Location:           /home/ss141213/.cache/.fr-tH6b6n/
 * Qualified Name:     javax.xml.ws.spi.FactoryFinder
 * JD-Core Version:    0.6.0
 */
